@@ -34,9 +34,7 @@ class PostGISAdapter:
             raise Exception('Error implementing psycopg2 protocol. Is psycopg2 installed?')
 
     def __eq__(self, other):
-        if not isinstance(other, PostGISAdapter):
-            return False
-        return self.ewkb == other.ewkb
+        return isinstance(other, PostGISAdapter) and self.ewkb == other.ewkb
 
     def __hash__(self):
         return hash(self.ewkb)
@@ -44,6 +42,10 @@ class PostGISAdapter:
     def __str__(self):
         return self.getquoted()
 
+    @classmethod
+    def _fix_polygon(cls, poly):
+        return poly
+
     def prepare(self, conn):
         """
         This method allows escaping the binary in the style required by the
